# python-package-backend-template
To create local package and remote package layers (not to create GraphQL and REST-API layers)

#database scripts
Please place <table-name>.py in /db 
No need for seperate file for _ml table
  
<table-name]_insert.py to create records

Update the setup.py (i.e.name)
